# Generated by Django 4.2.11 on 2025-02-13 16:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("h_admin", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="frontend",
            name="account_type",
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
