# Generated by Django 4.2.11 on 2025-02-13 13:34

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Frontend",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("flow_title", models.CharField(max_length=255)),
                ("flow_description", models.TextField()),
                ("switch_description", models.TextField()),
                ("sign_in_description", models.TextField()),
                ("register_description", models.TextField()),
                ("forgot_description", models.TextField()),
                ("reset_description", models.TextField()),
                ("authenticated_route", models.CharField(max_length=255)),
            ],
            options={
                "verbose_name_plural": "Frontend",
            },
        ),
        migrations.CreateModel(
            name="ServiceType",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, unique=True)),
                ("description", models.TextField()),
            ],
            options={
                "verbose_name_plural": "Service Types",
            },
        ),
        migrations.CreateModel(
            name="Identity",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255)),
                ("description", models.TextField()),
                (
                    "enable_admin",
                    models.BooleanField(default=False, verbose_name="Enable Admin"),
                ),
                (
                    "frontend",
                    models.ForeignKey(
                        editable=False,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="h_admin.frontend",
                    ),
                ),
                (
                    "service_type",
                    models.ForeignKey(
                        editable=False,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="h_admin.servicetype",
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "Identity",
            },
        ),
    ]
